#
# spec file for package ghc-generic-deriving
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name generic-deriving
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        1.12.3
Release:        1.6
Summary:        Generic programming library for generalised deriving
License:        BSD-3-Clause
Group:          Development/Libraries/Haskell
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-containers-devel
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-template-haskell-devel
BuildRequires:  ghc-th-abstraction-devel
%if %{with tests}
BuildRequires:  ghc-hspec-devel
%endif

%description
This package provides functionality for generalising the deriving mechanism in
Haskell to arbitrary classes. It was first described in the paper:

* /A generic deriving mechanism for Haskell/. Jose Pedro Magalhaes, Atze
Dijkstra, Johan Jeuring, and Andres Loeh. Haskell'10.

The current implementation integrates with the new GHC Generics. See
<http://www.haskell.org/haskellwiki/GHC.Generics> for more information.
Template Haskell code is provided for supporting older GHCs.

%package devel
Summary:        Haskell %{pkg_name} library development files
Group:          Development/Libraries/Haskell
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development
files.

%prep
%setup -q -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc CHANGELOG.md README.md

%changelog
* Tue Feb 12 2019 psimons@suse.com
- Update generic-deriving to version 1.12.3.
  [#] 1.12.3 [2019.02.09]
  * Support `template-haskell-2.15`.
  * Add a `gshowList` method to `GShow`, which lets us avoid the need for
    `OverlappingInstances` in `Generics.Deriving.TH`. As a consequence, the
    `GShow String` instance has been removed, as it is now fully subsumed by
    the `GShow [a]` instance (with which it previously overlapped).
  * Functions in `Generics.Deriving.TH` now balance groups of `(:*:)` and `(:+:)`
    as much as possible (`deriving Generic` was already performing this
    optimization, and now `generic-deriving` does too).
  * Add a `Generics.Deriving.Default` module demonstrating and explaining
    how and why to use `DerivingVia`. There is also a test suite with
    further examples.
* Wed Dec 26 2018 psimons@suse.com
- Add generic-deriving at version 1.12.2.
